@@ -6,10 +6,11 @@
 #' -- RR, or odds ratio -- OR) and difference measures (risk difference -- RD).
 #'
 #' The analytic approach uses the "relative risk due to confounding" as defined by
-#' Miettinen (1972), i.e. \eqn{RR_adj = \frac{RR_crude}{RR_conf}} where RR_adj is the
-#' standardized (adjusted) risk ratio, RR_crude is the crude risk ratio, and RR_conf
-#' is the relative risk component attributable to confounding by the stratification
-#' factors. The output provides both RR_adj (SMR or Mantel-Haenszel) and the RR_conf.
+#' Miettinen (1972), i.e. \eqn{RR_{adj} = \frac{RR_{crude}}{RR_{conf}}} where RR_adj
+#' is the standardized (adjusted) risk ratio, RR_crude is the crude risk ratio, and
+#' RR_conf is the relative risk component attributable to confounding by the
+#' stratification factors. The output provides both RR_adj (SMR or Mantel-Haenszel)
+#' and the RR_conf.
 #'
 #' @param case Outcome variable. If a variable, this variable is tabulated against.
 #' @param exposed Exposure variable.
@@ -93,10 +94,10 @@ confounders <- function(case,
         tab <- tab.df[2:1, 2:1]
     }
 
-    a <- tab[1, 1]
-    b <- tab[1, 2]
-    c <- tab[2, 1]
-    d <- tab[2, 2]
+    a <- as.numeric(tab[1, 1])
+    b <- as.numeric(tab[1, 2])
+    c <- as.numeric(tab[2, 1])
+    d <- as.numeric(tab[2, 2])
 
     type <- match.arg(type)
     if (type == "RR") {
